==> equity-base-0.5.28-RELEASE-sources.jar: com/rocogz/syy/equity/dto/equity/userCoupon/UserCouponExchangeRecordSearchParamDto.java <==
package com.rocogz.syy.equity.dto.equity.userCoupon;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Data;

/**
 * <dl>
 * <dd>Description: 用户积分券兑换记录查询条件 dto</dd>
 * <dd>Company: 广州大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021-09-04 16:44:36</dd>
 * <dd>@author：Andy</dd>
 * </dl>
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class UserCouponExchangeRecordSearchParamDto {

    /**
     * miniAppid
     */
    private String miniAppids;

    /**
     * 兑换订单号
     */
    private String orderCode;

    /**
     * 用户券编号
     */
    private String userCouponCode;

    /**
     * 业务单号
     */
    private String applyNo;

    /**
     * 清单编号
     */
    private String applyDetailCode;

    /**
     * 发放主体编号
     */
    private String sourceCodes;

    /**
     * 团队编号
     */
    private String teamCodes;

    /**
     * 发放人
     */
    private String createUser;

    /**
     * 发放人手机号
     */
    private String createMobile;

    /**
     * 发放月份
     */
    private String createMonth;

    /**
     * 发放开始日期
     */
    private String createStartDate;

    /**
     * 发放结束日期
     */
    private String createEndDate;

    /**
     * 领取月份
     */
    private String receiveMonth;

    /**
     * 领取开始日期
     */
    private String receiveStartDate;

    /**
     * 领取结束日期
     */
    private String receiveEndDate;

    /**
     * 兑换人手机号
     */
    private String exchangeMobile;

    /**
     * 兑换月份
     */
    private String exchangeMonth;

    /**
     * 兑换开始日期
     */
    private String exchangeStartDate;

    /**
     * 兑换结束日期
     */
    private String exchangeEndDate;

    /**
     * 页码
     */
    private int page;

    /**
     * 每页记录数
     */
    private int limit;

}

==> equity-base-0.6.6-RELEASE-sources.jar: com/rocogz/syy/equity/dto/equity/userCoupon/UserCouponExchangeRecordSearchParamDto.java <==
package com.rocogz.syy.equity.dto.equity.userCoupon;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Data;

/**
 * <dl>
 * <dd>Description: 用户积分券兑换记录查询条件 dto</dd>
 * <dd>Company: 广州大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021-09-04 16:44:36</dd>
 * <dd>@author：Andy</dd>
 * @description Andy 2022-01-05 17:17:03 新增发券性质参数
 * </dl>
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class UserCouponExchangeRecordSearchParamDto {

    /**
     * miniAppid
     */
    private String miniAppids;

    /**
     * 兑换订单号
     */
    private String orderCode;

    /**
     * 用户券编号
     */
    private String userCouponCode;

    /**
     * 业务单号
     */
    private String applyNo;

    /**
     * 清单编号
     */
    private String applyDetailCode;

    /**
     * 发放主体编号
     */
    private String sourceCodes;

    /**
     * 团队编号
     */
    private String teamCodes;

    /**
     * 发放人
     */
    private String createUser;

    /**
     * 发放人手机号
     */
    private String createMobile;

    /**
     * 发放月份
     */
    private String createMonth;

    /**
     * 发放开始日期
     */
    private String createStartDate;

    /**
     * 发放结束日期
     */
    private String createEndDate;

    /**
     * 领取月份
     */
    private String receiveMonth;

    /**
     * 领取开始日期
     */
    private String receiveStartDate;

    /**
     * 领取结束日期
     */
    private String receiveEndDate;

    /**
     * 兑换人手机号
     */
    private String exchangeMobile;

    /**
     * 兑换月份
     */
    private String exchangeMonth;

    /**
     * 兑换开始日期
     */
    private String exchangeStartDate;

    /**
     * 兑换结束日期
     */
    private String exchangeEndDate;

    /**
     * 发券性质：NORMAL-正常发券，BUSINESS_VERIFY-业务验证
     */
    private String nature;

    /**
     * 页码
     */
    private int page;

    /**
     * 每页记录数
     */
    private int limit;

}
